####
NSoT
####

.. image:: https://raw.githubusercontent.com/dropbox/nsot/master/docs/_static/logo_128.png
   :alt: Network Source of Truth
   :width: 128px

|Build Status| |Documentation Status| |PyPI Status|

Network Source of Truth (NSoT) is a source of truth database and repository for
tracking inventory and metadata of network entities to ease management and
automation of network infrastructure.

NSoT is an API-first application that provides a REST API and a web application
front-end for managing IP addresses (IPAM), network devices, and network
interfaces.

Resources
=========

+ `Documentation <http://nsot.readthedocs.io/>`_
+ `Python API client/CLI utility <http://pynsot.readthedocs.io/>`_
+ IRC: ``#nsot`` on ``irc.freenode.net``

.. |Build Status| image:: https://img.shields.io/travis/dropbox/nsot/master.svg?style=flat
   :target: https://travis-ci.org/dropbox/nsot
   :width: 88px
   :height: 20px
.. |Documentation Status| image:: https://readthedocs.org/projects/nsot/badge/?version=latest&style=flat
   :target: https://readthedocs.org/projects/nsot/?badge=latest
   :width: 76px
   :height: 20px
.. |PyPI Status| image:: https://img.shields.io/pypi/v/nsot.svg?style=flat
   :target: https://pypi.python.org/pypi/nsot
   :width: 68px
   :height: 20px
